@@ -121,3 +121,30 @@ class Face:
         self.show()
         self.message = ""
     
+
+    def smile(self):
+        """
+        笑った顔を表示する。
+        """
+        self.eye_kind = 0
+        self.mouth_kind = 0
+        self.eye_position = [0, 0]
+        self.eyeblow_position = [0, 0]
+        self.eyeblow_degree = 0
+        self.mouth_position = [0, 0]
+
+        self.show()
+
+
+    def angry(self):
+        """
+        起こった顔を表示する。
+        """
+        self.eye_kind = 2
+        self.mouth_kind = 1
+        self.eye_position = [0, 0]
+        self.eyeblow_position = [0, 0]
+        self.eyeblow_degree = 30
+        self.mouth_position = [0, 0]
+
+        self.show()
